import os, subprocess

from anouman.templates import (
    VagrantTemplate,
    VagrantBootstrapTemplate,
    CleanTemplate,
)

def build_vm(args):
    if not args.vm:
        raise Exception("build_vm must be callsed with args.mv=name")

    os.mkdir(args.vm)
    os.chdir(args.vm)
    # Write the Vagrantfile
    VagrantTemplate.save("Vagrantfile", context={
        'NAME':args.vm,
        'PUBLIC':True
    })

    # Write teh bootstrap file  
    VagrantBootstrapTemplate.save(path="./bootstrap.sh", context={
        'NGINX':True,
        'MYSQL':True,
    })

    # Write the clean file
    CleanTemplate.save(path="./clean.sh", context={'DOMAINNAME':'site3.com'})
    
    subprocess.call(['vagrant', 'up'])
    print "#########################################"
    print "#                                       #" 
    print "#   Your VM is ready.                   #"
    print "#   To login use the collowing command  #"
    print "#   ssh anouman@192.168.100.100         #"
    print "#                                       #"
    print "#########################################"



import random
import unittest

from django.conf import settings
settings.configure()

from anouman.templates import ShellCommandTemplate

class TestSequenceFunctions(unittest.TestCase):

    def setUp(self):
        self.seq = range(10)

    def test_shell_cmd_template(self):
        from test_expected_results import shell_commands_expected
        context = {
            'DOMAINNAME':'example.com',
        }
        
        out = ShellCommandTemplate.render(context) 
        self.assertTrue(out == shell_commands_expected)

if __name__ == '__main__':
    suite = unittest.TestLoader().loadTestsFromTestCase(TestSequenceFunctions)
    unittest.TextTestRunner(verbosity=2).run(suite)



"""
    Defining some Error base classes
"""

class MultipleError(Exception):
    def __init__(self, value):
        self.value = value
    def __str__(self):
        return repr(self.value)

class NotFoundError(Exception):
    def __init__(self, msg=''):
        self.msg = msg

    def __str__(self):
        return repr(self.msg)

"""
    settings.py related exceptions
"""
class MultipleSettingError(MultipleError):
    def __str__(self):
        out = repr(self.value)
        out = out + "\ntry running with --settings"
        return out

class NoSettingsError(NotFoundError):
    def __str__(self):
        if not self.msg:
            return "settings.py not found"
        
"""
    wsgi.py related exceptions
"""
class MultipleWSGIError(MultipleError):
    def __str__(self):
        out = repr(self.value)
        out = out + "\ntry running with --wsgi"
        return out

class NoWSGIError(NotFoundError):
    def __str__(self):
        if not self.msg:
            return "wsgi.py not found"

"""
    manage.py related exceptions
"""
class MultipleMANAGEError(MultipleError):
    def __str__(self):
        out = repr(self.value)
        out = out + "\ntry running with --manage"
        return out


class NoMANAGEError(NotFoundError):
    def __str__(self):
        if not self.msg:
            return "manage.py not found"





import os
import subprocess


from anouman.utils.find_files import (
    get_settings,
    get_wsgi,
)

def package_django_project(args):
    # settings is the full path
    # SETTINGS is the django projec path, exL  finance.settings
    [settings, SETTINGS] = get_settings(args)
    
    # TODO Should this all be done in deploy?    
    os.makedirs(args.domainname)
    os.makedirs("%s/bin"%(args.domainname))
    os.makedirs("%s/etc/nginx/sites-available"%(args.domainname))
    os.makedirs("%s/etc/init"%(args.domainname))

    """
        Install packages from project environment into the new virtualenv.
        Also store the status for success/fail as we install them
    """
    pip = subprocess.check_output(['which', 'pip'])
    print "pip: ", pip
    print "Saving pacakges to: ", "%s/pip_packages.txt"%(args.domainname)
    os.system("pip freeze > %s/pip_packages.txt"%(args.domainname))


    """
        Now we copy your django project into the virtual env
    """
    print "Copying your source tree into the virtual env"
    print "args.django_project: ", args.django_project
    print "args.domainname: ", args.domainname
    subprocess.call(['cp', '-r', args.django_project, args.domainname+"/src"]) 
    subprocess.call(['tar', '-cf', args.domainname+".tar", args.domainname])
    subprocess.call(['gzip', args.domainname+".tar"])
    subprocess.call(["rm", "-rf", args.domainname])


if __name__ == '__main__':
    print "This does nothing"
    pass



#!/usr/bin/env python
import os
from django.template import Template, Context
from django.conf import settings

settings.configure()

class BaseTemplate:
    """ 
        This is the base class for template rendering
        Each template to render should extend from this class and 
        override minimalliy the context and template properties.
    """

    # absolute path to the template file
    template = ''   

    # The context that will be passed to the template
    # Sublcasses should specify their own context parameters
    context = {}

    @classmethod
    def render(cls, c={}):
        """
            Pass in a context our the defaults above will be used
        """
        cls.context.update(c)
        t = Template( open(cls.template).read() )
        c = Context( cls.context )
        return t.render( c )

    @classmethod
    def save(cls, path, **kwargs):
        """
            path is the path to where the file will be saved
        """
        c = kwargs.get('context', cls.context)
        with open(path, 'w') as f:
            f.write(cls.render(c) )

class VagrantTemplate(BaseTemplate):
    template = os.path.dirname(os.path.realpath(__file__)) + "/Vagrantfile"
    context = {
        'NAME':'site1',
        'PRIVATE':'192.168.100.100', #To use private network set to ip:  192.168.100.100
    } 

class GunicornTemplate(BaseTemplate):
    template=os.path.dirname(os.path.realpath(__file__)) + "/gunicorn_start.sh"

    context = {
        'NAME':'website',                               # Name of the application
        'DJANGODIR':'./',                               # Django project director
        'USER':'username',                              # user to run as
        'GROUP':'username',                             # group to run as
        'NUM_WORKERS':3,                                # Number of Gunicorn threads.  2(proc)+1
        'VIRTUALENVDIR':'./virtualenv',                 # Directory containing your projects virtual env
        'DJANGO_SETTINGS_MODULE':'website.settings',    # the django settings file
        'DJANGO_WSGI_MODULE':'website.wsgi',            # your project wsgi module
        'GUNICORN':'virtualenv/bin/gunicorn',           # location of gunicorn.py
        'ERROR_LOG':'/var/log/gunicorn-error.log',      # recommend setting this to domain/logs/gunicorn-error.log
        'ACCESS_LOG':'/var/log/gunicorn-access.log',    # recommend setting this to domain/logs/gunicorn-error.log
        'SOCKFILE':False,                               # ex:  /var/run/gunicorn.sock 
        #   You can bind your server to a unix socket or to a port
        #   But you should only bind it to one or the other
        #   unix socket example: /var/run/gunicorn.sock
        #   ip:port example:    10.0.2.13:8000
        'BIND':False,                                   # ex:  10.0.2.13:80  Use
    }

class NginxTemplate(BaseTemplate):
    template=os.path.dirname(os.path.realpath(__file__)) + "/nginx.conf"
    context = {
        'UNIXBIND':'',
        'DOMAINNAME':'',
        'DJANGO_STATIC':'',
        'DJANGO_MEDIA':'',
        'ACCESS_LOG':'',    # Project/Site based logs
        'ERROR_LOG':''      # Project/Site based logs
    }

class VagrantBootstrapTemplate(BaseTemplate):
    template=os.path.dirname(os.path.realpath(__file__)) + "/vagrant_bootstrap.sh"

    context = {
        'NGINX':True,
        'MYSQL':False,
    }

class UpstateTemplate(BaseTemplate):
    template=os.path.dirname(os.path.realpath(__file__)) + "/upstart.conf"

    context = {
        'GUNICORN_START':'',    # The abspath to the gunicorn_start script
        'DOMAINNAME':'',        # The domain name
    }    


class ShellCommandTemplate(BaseTemplate):
    template=os.path.dirname(os.path.realpath(__file__)) + "/shell_commands"

    context = {
        'DOMAINNAME':'',
    }

    @classmethod
    def save(cls, path="./site.conf", **kwargs):
        """
            Overridden because we need to append and not write to the activate file
        """
        c = kwargs.get('context', cls.context)
        with open(path, 'a') as f:
            f.write(cls.render(c) ) 


class CleanTemplate(BaseTemplate):
    template=os.path.dirname(os.path.realpath(__file__)) + "/clean.sh"

    context = {
        'DOMAINNAME':'site1.com',
    }




import os, sys, re
import fnmatch

from anouman.exceptions import (
    MultipleSettingError,
    NoSettingsError,
    MultipleWSGIError,
    NoWSGIError,
    MultipleMANAGEError,
    NoMANAGEError,
)

def find_file(root_dir, pattern):
    """
        This is a generic recursive grep function
    """
    matches = []
    for root, dirnames, filenames in os.walk(root_dir):
        for filename in fnmatch.filter(filenames, pattern):
            matches.append(os.path.join(root, filename))
    return matches

def get_settings(args):
    """
        This function checks for the existence of the settings file.

        If the --settings options is specified then we simply
        check to see if the file exists and if so return the name of the
        file.

        If no --settings option was given then we look for settings.py
        recursivly in the directory defined by --django-project.
          -- If multiple settings.py are found we throw an exception.
          -- If not settings.py is found we throw an exception.
          -- If one settings.py is found we return it's path.
    """
    settings_path=''
    if not args.settings:
        matches = find_file(args.django_project, 'settings.py')
        if len(matches) > 1:
            raise MultipleSettingError(matches)
        elif len(matches) == 0:
            print "args.django_project: ", args.django_project
            print "search path: %s"%(os.path.abspath(args.django_project))
            raise NoSettingsError()
        settings_path= matches[0]
    elif not os.path.isfile(args.settings):
        raise NoSettingsError() 
    else:
        settings_path = args.settings
   
    # We now have the path to the settings.py modules, but we need
    # to convert it to python module format:  settings.wsgi
    tmp = settings_path.split(args.django_project)
    if len(tmp) == 2:
        return [
            os.path.abspath(settings_path), 
            tmp[1][1:].replace("/", ".").replace(".py", "")
        ]
    else:
        raise NoSettingsError( str(tmp) )
    
def get_wsgi(args):
    """
        This function checks for the existence of the wsgi.py file.

        If the --wsgi options is specified then we simply
        check to see if the file exists and if so return the name of the
        file.

        If no --wsgi option was given then we look for wsgi.py
        recursivly in the directory defined by --django-project.
          -- If multiple wsgi.py are found we throw an exception.
          -- If not wsgi.py is found we throw an exception.
          -- If one wsgi.py is found we return it's path.
    """
    wsgi_path = ''
    if not args.wsgi:
        matches = find_file(args.django_project, 'wsgi.py')
        if len(matches) > 1:
            raise MultipleWSGIError(matches)
        if len(matches) == 0:
            raise NoWSGIError()
        wsgi_path=os.path.abspath( matches[0] )
    elif not os.path.isfile(args.wsgi):
        raise NoWSGIError() 
    else:
        wsgi_path = os.path.abspath( args.wsgi )

    # We now have the path to the wsgi.py modules, but we need
    # to convert it to python module format:  website.wsgi
    tmp = wsgi_path.split( os.path.abspath(args.django_project) )
    if len(tmp) == 2:
        return tmp[1][1:].replace("/", ".").replace(".py", "")
    else:
        raise NoWSGIError( str(tmp) )

def get_manage(args):
    """
        This function checks for the existence of the manage.py file.

        If the --manage options is specified then we simply
        check to see if the file exists and if so return the name of the
        file.

        If no --manage option was given then we look for manage.py
        recursivly in the directory defined by --django-project.
          -- If multiple manage.py are found we throw an exception.
          -- If not manage.py is found we throw an exception.
          -- If one manage.py is found we return it's path.
    """
    manage_path = ''
    if not args.manage:
        matches = find_file(args.django_project, 'manage.py')
        if len(matches) > 1:
            raise MultipleMANAGEError(matches)
        if len(matches) == 0:
            raise NoMANAGEError()
        manage_path = matches[0]
    elif not os.path.isfile(args.manage):
        raise NoMANAGEError()
    else:
        manage_path = os.path.abspath( args.manage )

    return os.path.abspath( manage_path )

def change_settings(settings_file, pattern, value):
    with  open(settings_file, 'r') as f:
        contents = f.readlines()

    match_count = 0
    for line in contents:
        if pattern in line and "#" not in line:
            match_count = match_count + 1

    
    if match_count > 1:
        print "WARNING:  More than one %s line in settings file." %(pattern)
        print "Anouman would prefer to have you set this value yourself or remove duplicate %s settings" %(pattern)
        return False

    new_contents = []
    for line in contents:
        if pattern in line and "#" not in line:
            line = "#"+line
            new_contents.append(line)
            new_contents.append('%s="%s"'%(pattern, value) )
        else:
            new_contents.append(line)

    with open(settings_file, 'w') as f:
        f.writelines(new_contents)

    # Flush the stdout buffer and force write to disk
    sys.stdout.flush()

    return True

def set_static_roots(args):
    """
        We need to change the STATIC_ROOT and MEDIA_ROOT variables
    """
    [settings_path, SETTINGS] = get_settings(args)
    sys.path.append(os.path.dirname(settings_path))
    import settings
    
    change_settings(settings_path, r'MEDIA_ROOT', "%s/"%(os.path.abspath("%s/media/" %(args.domainname))) )
    change_settings(settings_path, r'STATIC_ROOT', "%s/"%(os.path.abspath("%s/static/" %(args.domainname))) )

    reload(settings)

    return [settings.STATIC_ROOT, settings.MEDIA_ROOT]



#!/usr/bin/env python
import os 
import argparse

from anouman.project.setup import package_django_project
from anouman.project.create_vm import build_vm
from anouman.project.deploy import Deploy

descr="""
    anouman is a django 1.4+ deployment simplifier.

    You provide anouman a django project and anouman provides
    you a fully deployable anouman package (aka tarball)
    
    NOTE:  anouman
    Currently we can deploy project based on django 1.4 and up.
"""

def get_args():
    parser = argparse.ArgumentParser(
        description=descr
    )
    
    parser.add_argument('--vm',
        help='Create a virtual machine.  Pass it the VM name',
        dest='vm',
        default="",
    )

    parser.add_argument('--domainname',
        help='Enter the domain name of your website',
        dest='domainname',
        default="www.example.com",
    )

    parser.add_argument('--startproject',
        help='Start a new django project with default option nginx/gunicorn',
        dest='project_name',
        default=False,
    )

    parser.add_argument('--django-version',
        help='Set the django version.  Default to latest version pip repo.  (ex:  ==1.5.1) note the ==',
        dest='django_version',
        default='>=1.5, <=1.6',
    )
    
    parser.add_argument('--django-project',
        help='Create deployment for django project.  (Assumes one settings file and one wsgi file)',
        dest='django_project',
        default=False,
    )
    
    parser.add_argument('--settings',
        help='Specify path to settings.py',
        dest='settings',
        default=False,
    )

    parser.add_argument('--wsgi',
        help='Specify path to wsgi.py',
        dest='wsgi',
        default=False,
    )

    parser.add_argument('--manage',
        help='Specify the path to your projects manage.py scrpt',
        dest='manage',
        default=False,
    )

    parser.add_argument('--virtualenv',
        help='Set the virtualev directory.',
        dest='virtualenv',
        default='virtualenv',
    )
    
    parser.add_argument('--bind',
        help='Set the virtualev directory.',
        dest='bind',
        default=False, #ex:  10.0.1.13:8001
    )
    
    parser.add_argument('--gunicorn',
        help='use gunicorn as the django server',
        dest='gunicorn',
        action='store_true',
        default=True,
    )

    parser.add_argument('--deploy',
        help='deploy the project',
        dest='deploy',
        default=False,
    )
    
    parser.add_argument('--setup',
        help='setup anouman',
        dest='setup',
        action='store_true',
        default=False,
    )

    parser.add_argument('--mysql',
        help='setup for mysql backed database',
        dest='mysql',
        action='store_true',
        default=True,
    )

    args = parser.parse_args()

    if args.django_project:
        args.django_project = os.path.abspath(args.django_project)

    """ By default (neither --socket nor --bind is explicitly passed in) 
        we bind to --socket=unix:/var/run/your_project.sock
        If the --bind={10.0.1.13:8000} option is used
        the --socket default is overridden...Even if you pass 
        --socket yourself.  If
    """
    if args.bind:
        args.socket=False

    return args



if __name__ == '__main__':
    print "anouman"
    args = get_args()
    
    if args.vm:
       build_vm(args) 

    # Project Packaging
    if args.django_project:
        package_django_project(args)
    
    # Project Deploying
    if args.deploy:
        Deploy(args)

    # This is for creating a brand new django project
    # TODO do we still want to go this route???
    if args.project_name:
        setup.new_project( args )


    



import os, stat, shutil
from os.path import expanduser
import getpass
import subprocess


from anouman.templates import (
    GunicornTemplate,
    UpstateTemplate,
    NginxTemplate,
    ShellCommandTemplate,
)

from anouman.utils.find_files import (
    get_settings,
    get_wsgi,
    get_manage,
    set_static_roots,
)


class Deploy():
    """
        To Deploy a site simply call Deploy(args)
    """
    def __init__(self, args):
        # Next we unpack the project
        # subproces, tar returns zero on success...
        if subprocess.call(["tar", "xvfz", args.deploy]):
            raise Exception( "Call to subprocess failed on tar unpack" )
        
        # Set both args.domainname  AND args.django_project to the deploy basename
        args.domainname = args.deploy.split(".tar.gz")[0]
        args.django_project=args.domainname+"/src"
   
        home = expanduser("~")
        # absolute path to the virtualenv
        self.VIRTUALENV = home+"/.virtualenvs/%s"%(args.domainname)

        # absoluate path to virtualenv/bin/
        self.VIRTBIN=os.path.abspath("%s/bin"%(self.VIRTUALENV))

        # absolute path to the virtualenv pip
        self.PIP="%s/pip"%(self.VIRTBIN)

        # absolute path the virtualenv python interpretor
        self.PYTHON="%s/python"%(self.VIRTBIN)

        # absolute path the vitualenv activate script
        self.ACTIVATE="%s/activate"%(self.VIRTBIN)

        # absolute path to the project LOGDIR
        self.LOG_DIR = os.getcwd() +"/%s/logs"%(args.domainname)

        # absolute path to the gunicorn_start.sh script
        self.GUNICORN_START="%s/gunicorn_start"%(self.VIRTBIN)

        # SETTINGS project path:  ex  project.settings
        # settings absolute path to the settings.py
        [self.settings, self.SETTINGS] = get_settings(args)    

        # absolute path to the project wsgi.py
        self.WSGI = get_wsgi(args) 

        # absolute path to manage.py
        self.MANAGE = get_manage(args) #get abspath of manage.py

        # Create log directory if it doesn't exist
        if not os.path.isdir(self.LOG_DIR):
            os.makedirs(self.LOG_DIR)

        
        self.deploy_django_project(args)

    
    def deploy_django_project(self, args):
        """
            This is the primary deploy method
        """

        # Create a virtualenv
        subprocess.call(["virtualenv", self.VIRTUALENV])

        # Append anouman shell command to activate script
        ShellCommandTemplate.save(self.ACTIVATE, context={'DOMAINNAME':args.domainname})

        # Create the gunicorn_start.sh file
        self.Setup_Gunicorn_Start(args)

        # Create the upstart files in /etc/init
        self.SetupUpstart(args)

        # Create the NGINX files
        self.SetupNGINX(args)

        # Install the python packages
        self.install_python_packages(args)

        # Run collectstatic command
        #subprocess.call([self.PYTHON, self.MANAGE, "collectstatic"])
        print '''/bin/echo "yes" | %s %s collectstatic'''%(self.PYTHON, self.MANAGE)
        os.system( '''/bin/echo "yes" | %s %s collectstatic'''%(self.PYTHON, self.MANAGE) )
        #subprocess.call(['''/bin/echo "yes" | %s %s collectstatic'''%(self.PYTHON, self.MANAGE)])

        """
            Print output message
        """
        print "#######################################################################"
        print "                                                                       "    
        print "                        SETUP COMPLETE                                 "    
        print "                                                                       "    
        print "         Please add the following line(s) to your .bash_profile        "
        print "                                                                       "    
        print "         source /usr/local/bin/virtualenvwrapper.sh                    "
        print "         workon %s                                                     "%(args.domainname)
        print "                                                                       "    
        print "         Then call source on .bash_profile                             "
        print "         $source ~/.bash_profile                                       "
        print "                                                                       "    
        print "#######################################################################"



    def SetupNGINX(self, args):
        """
            nginx script for the site.
            place in:   domainname/etc/nginx/sites-available
            and in:     /etc/nginx/sites-available
            link to:    /etc/nginx/sites-enabled 

            Anouman should eventually be able to bring your sites on       
            and off line simple by removing the symlink

            Must pass an args with minimally:
            args.domainname
            args.django_project OR args.settings
        """

        # update STATIC_ROOT and MEDIA_ROOT in settings.py to reflect the install location
        [self.STATIC_ROOT, self.MEDIA_ROOT] = set_static_roots(args)
        
        # Create the project etc/nginx/sites_available directory
        if not os.path.exists( "%s/etc/nginx/sites-available/"%(args.domainname) ):
            os.makedirs("%s/etc/nginx/sites-available/"%(args.domainname) )

        # Save nginx config ot project/etc/nginx/sites-available
        NGINX_CONF="%s/etc/nginx/sites-available/%s"%(args.domainname, args.domainname)
        NginxTemplate.save(NGINX_CONF, context={
            'UNIXBIND':'unix:/var/run/%s.sock' %(args.domainname),
            'DOMAINNAME':args.domainname,
            'DJANGO_STATIC':self.STATIC_ROOT,
            'DJANGO_MEDIA':self.MEDIA_ROOT,
            'ACCESS_LOG':"%s/nginx-access.log"%(self.LOG_DIR),
            'ERROR_LOG':"%s/nginx-error.log"%(self.LOG_DIR),
        })

        # Remove any prior installs
        os.system("rm -f /etc/nginx/sites-available/%(dn)s /etc/nginx/sites-enabled/%(dn)s"% {'dn':args.domainname} )

        # Copy the /etc/nginx files to /etc/nginx
        os.system("sudo cp -r %s/etc/nginx/* /etc/nginx/" %(args.domainname))
       
        # Symlink sites-available to sites enabled 
        os.system("sudo ln -s /etc/nginx/sites-available/%(dn)s /etc/nginx/sites-enabled/%(dn)s"% {'dn':args.domainname} )


    def SetupUpstart(self, args):
        """
            Now we create the gunicorn upstart scripts
        """
        NAME=args.domainname+".conf"

        UpstateTemplate.save(NAME, context={
            'GUNICORN_START':self.GUNICORN_START,
            'DOMAINNAME':args.domainname,
        })

        os.system("sudo mv %s /etc/init/%s"%(NAME, NAME) )


    def Setup_Gunicorn_Start(self, args):
        """
            Setup and install gunicorn_start.sh on the server
            
            default context located: anouman/templates/gunicorn_start.sh
            install location  {virtenv}/bin/gunicorn_start.sh
        """

        # set DJANGODIR env variable to abspath of project root.
        NAME=os.path.basename(args.django_project)
        DJANGODIR=os.path.abspath(args.domainname + "/" + NAME)

        GunicornTemplate.save(self.GUNICORN_START, context={
            'NAME':args.domainname,
            'USER':getpass.getuser(),
            'GROUP':getpass.getuser(),
            'GUNICORN':"%s/gunicorn"%(self.VIRTBIN),
            'DJANGODIR':DJANGODIR,
            'DJANGO_SETTINGS_MODULE':self.SETTINGS,
            'DJANGO_WSGI_MODULE':self.WSGI,
            'ACCESS_LOG':"%s/gunicorn-access.log"%(self.LOG_DIR),
            'ERROR_LOG':"%s/gunicorn-error.log"%(self.LOG_DIR),
            'BIND':args.bind if args.bind else 'unix:/var/run/%s.sock' %(args.domainname),
        })

        # Set Permissions on the GUNICORN file
        os.chmod(self.GUNICORN_START, stat.S_IRWXU|stat.S_IRWXG|stat.S_IXOTH)

        return self.GUNICORN_START

    def install_python_packages(self, args):
        """
            This section installs the users python packages into their site virtualenv
            TODO:  This should have better reporting for failing packages
        """
        pkg_success = []
        pgk_fails = []
        with open("%s/pip_packages.txt"%(args.domainname)) as f:
            PACKAGES = f.readlines()
            PACKAGES.append("gunicorn")
            for package in PACKAGES:
                try:
                    subprocess.call([self.PIP, "install", package])
                    pkg_success.append(package)
                except:
                    pgk_fails.append(package)
    
        subprocess.call([self.PIP, "install", "-r", "%s/pip_packages.txt"%(args.domainname)])
        print "Package Installation Results"
        print "SUCCESS: %s" %(len(pkg_success))
        print "FAIL:    %s" %(len(pgk_fails))
        for f in pgk_fails:
            print "\t*\t%s"%(f)



if __name__ == '__main__':
    print "This does nothing"
    pass



#!/usr/bin/env python

shell_commands_expected="""
#This section defines commands specified by Anouman

NGINX=/etc/init.d/nginx
DOMAINNAME=example.com

function site {
        if [ $1 == 'status' ];
        then
                sudo $NGINX status
                sudo status $DOMAINNAME
        fi

        if [ $1 == 'stop' ];
        then
                sudo $NGINX stop
                sudo stop $DOMAINNAME
        fi

        if [ $1 == 'start' ];
        then
                sudo $NGINX start
                sudo start $DOMAINNAME
        fi

        if [ $1 == 'reload' ];
        then
                sudo nginx -s reload
        fi
}"""
